@@ -1,5 +1,5 @@
 
-# $Id: Ethernet.pm,v 1.64 2004/11/13 14:00:50 Daddy Exp $
+# $Id: Ethernet.pm,v 1.65 2005/01/05 15:39:35 Daddy Exp $
 
 =head1 NAME
 
@@ -30,10 +30,11 @@ use strict;
 
 use constant DEBUG_LINUX => 0;
 use constant DEBUG_SOLARIS => 0;
+use constant DEBUG_IPCONFIG => 0;
 
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
 @ISA = qw( Exporter );
-$VERSION = do { my @r = (q$Revision: 1.64 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.65 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 %EXPORT_TAGS = ( 'all' => [ qw( get_address method canonical is_address ), ], );
 @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
@@ -62,6 +63,7 @@ sub get_address
     {
     my @asAddr;
     my @as = qx{ ipconfig /all };
+    chomp @as;
  LINE_IPCONFIG:
     foreach my $sLine (@as)
       {
@@ -72,13 +74,19 @@ sub get_address
                       )}ix)
         {
         # Found a Physical Address line.
+        print STDERR " DDD found phys line ==$sLine==\n" if (DEBUG_IPCONFIG || $ENV{N_A_E_DEBUG});
         if ($sLine =~ m!((?:$b$b-){5}$b$b)!)
           {
           # Matched the 6-byte ethernet address:
           $sAddr = $1;
+          print STDERR " DDD   found addr ==$sAddr==\n" if (DEBUG_IPCONFIG || $ENV{N_A_E_DEBUG});
           push @asAddr, $sAddr;
           # Don't return it until we make sure this adapter is active!
           } # found the ethernet address
+        else
+          {
+          print STDERR " DDD   but no addr!\n" if (DEBUG_IPCONFIG || $ENV{N_A_E_DEBUG});
+          }
         } # found "Physical Address"
       elsif (
              # This adapter shows a real IP address:
@@ -94,13 +102,19 @@ sub get_address
              ($sLine !~ m!\s0.0.0.0!i)
             )
         {
+        print STDERR " DDD found ip   line ==$sLine==\n" if (DEBUG_IPCONFIG || $ENV{N_A_E_DEBUG});
         if ($sAddr ne '')
           {
           # We've already seen the ethernet address; return it:
           $sMethod = 'ipconfig';
           last LINE_IPCONFIG;
           } # we've already seen the physical address
+        print STDERR " DDD   but no physical address line yet.\n" if (DEBUG_IPCONFIG || $ENV{N_A_E_DEBUG});
         } # found a non-zero IP address
+      else
+        {
+        print STDERR " DDD some other line ==$sLine==\n" if (DEBUG_IPCONFIG || $ENV{N_A_E_DEBUG});
+        }
       } # foreach LINE_IPCONFIG
     # If we get here, then no adapters were active.
     if (scalar(@asAddr) == 1)
@@ -108,7 +122,8 @@ sub get_address
       # There was only one MAC address found; return it even though it
       # is not active:
       $sAddr = shift @asAddr;
-      }
+      $sMethod = 'ipconfig';
+      } # if only one MAC found
     } # if Win32
   elsif ($^O =~ m!linux!i)
     {
